==> downloads.html?file=gigkalender_v1.2.61_069.zip: gigkalender/install/iniGigs.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
function iniGigs () {
global $prefix;
global $db_name;
global $CharsGigCountry;
global $CharsGigDistrict;
global $CharsGigCity;
global $CharsGigCity;
global $CharsGigEventURL; 
global $CharsGigVenue;
global $CharsGigVenueURL; 
global $CharsGigEntranceFee; 
global $CharsGigOrganizer; 
global $CharsGigOrganizerURL; 
global $CharsGigLineup; 
global $CharsGigVisitors;
global $CharsGigEvent;
global $CharsGigStageBuilding; 
global $CharsGigBeginning; 
global $CharsGigDuration; 
global $CharsGigEnding; 
global $CharsGigStatus; 
global $CharsGigArtist;
global $CharsGigArtistURL;
global $CharsUserName;

// Tabellenfelder definieren
  $SQL_Befehl = 'CREATE TABLE '.$prefix.'gigs
    (
     GigID INTEGER NOT NULL AUTO_INCREMENT,
     GigDate INT,
     GigCountry CHAR('.$CharsGigCountry.'),
     GigDistrict CHAR('.$CharsGigDistrict.'),
     GigPostalCode INT,
     GigCity CHAR('.$CharsGigCity.'),
     GigEvent CHAR('.$CharsGigEvent.'),
     GigEventURL CHAR('.$CharsGigEventURL.'),
     GigVenue CHAR('.$CharsGigVenue.'),
     GigVenueURL CHAR('.$CharsGigVenueURL.'),
     GigEntranceFee CHAR('.$CharsGigEntranceFee.'),
     GigOrganizer CHAR('.$CharsGigOrganizer.'),
     GigOrganizerURL CHAR('.$CharsGigOrganizerURL.'),
     GigLineup CHAR('.$CharsGigLineup.'),
     GigVisitors CHAR('.$CharsGigVisitors.'),
     GigStageBuilding CHAR('.$CharsGigStageBuilding.'),
     GigBeginning CHAR('.$CharsGigBeginning.'),
     GigDuration CHAR('.$CharsGigDuration.'),
     GigEnding CHAR('.$CharsGigEnding.'),
     GigNotes TEXT,
     GigStatus CHAR('.$CharsGigStatus.'),
     GigPublish TINYINT(1),
     GigIsPrivate TINYINT(1),
     GigArtist CHAR('.$CharsGigArtist.'),
     GigArtistURL CHAR('.$CharsGigArtistURL.'),
     GigDateOfLastEdit INT,
     GigLastEditor CHAR('.$CharsUserName.'),
     GigAddedFrom CHAR ('.$CharsUserName.'),
     GigDateOfAdding INT,
     PRIMARY KEY (GigID),
     UNIQUE (GigID)
    ) ENGINE = MYISAM CHARACTER SET utf8 COLLATE utf8_unicode_ci';

// Tabelle erzeugen und pruefen
    if (mysql_db_query($db_name, $SQL_Befehl))
    {
      return true;
    }
    else
    {
      return false;
    }
}
?>

==> downloads.html?file=gigkalender_v1.2.75_017.zip: gigkalender/install/iniGigs.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
function iniGigs () {
global $prefix;
global $db;
global $CharsGigCountry;
global $CharsGigDistrict;
global $CharsGigPostcode;
global $CharsGigCity;
global $CharsGigCity;
global $CharsGigEventURL; 
global $CharsGigVenue;
global $CharsGigVenueURL; 
global $CharsGigEntranceFee; 
global $CharsGigOrganizer; 
global $CharsGigOrganizerURL; 
global $CharsGigLineup; 
global $CharsGigVisitors;
global $CharsGigEvent;
global $CharsGigStageBuilding; 
global $CharsGigBeginning; 
global $CharsGigDuration; 
global $CharsGigEnding; 
global $CharsGigStatus; 
global $CharsGigArtist;
global $CharsGigArtistURL;
global $CharsUserName;

// Tabellenfelder definieren
  $SQL_Befehl = 'CREATE TABLE '.$prefix.'gigs
    (
     GigID INTEGER NOT NULL AUTO_INCREMENT,
     GigDate INT,
     GigCountry CHAR('.$CharsGigCountry.'),
     GigDistrict CHAR('.$CharsGigDistrict.'),
     GigPostalCode CHAR('.$CharsGigPostcode.'),
     GigCity CHAR('.$CharsGigCity.'),
     GigEvent CHAR('.$CharsGigEvent.'),
     GigEventURL CHAR('.$CharsGigEventURL.'),
     GigVenue CHAR('.$CharsGigVenue.'),
     GigVenueURL CHAR('.$CharsGigVenueURL.'),
     GigEntranceFee CHAR('.$CharsGigEntranceFee.'),
     GigOrganizer CHAR('.$CharsGigOrganizer.'),
     GigOrganizerURL CHAR('.$CharsGigOrganizerURL.'),
     GigLineup CHAR('.$CharsGigLineup.'),
     GigVisitors CHAR('.$CharsGigVisitors.'),
     GigStageBuilding CHAR('.$CharsGigStageBuilding.'),
     GigBeginning CHAR('.$CharsGigBeginning.'),
     GigDuration CHAR('.$CharsGigDuration.'),
     GigEnding CHAR('.$CharsGigEnding.'),
     GigNotes TEXT,
     GigStatus CHAR('.$CharsGigStatus.'),
     GigPublish TINYINT(1),
     GigIsPrivate TINYINT(1),
     GigArtist CHAR('.$CharsGigArtist.'),
     GigArtistURL CHAR('.$CharsGigArtistURL.'),
     GigDateOfLastEdit INT,
     GigLastEditor CHAR('.$CharsUserName.'),
     GigAddedFrom CHAR ('.$CharsUserName.'),
     GigDateOfAdding INT,
     PRIMARY KEY (GigID),
     UNIQUE (GigID)
    ) ENGINE = MYISAM CHARACTER SET utf8 COLLATE utf8_unicode_ci';

// Tabelle erzeugen und pruefen
    if (mysqli_query($db, $SQL_Befehl))
    {
      return true;
    }
    else
    {
      return false;
    }
}
?>
